@@ -19,21 +19,19 @@
 
 package org.apache.myfaces.tobago.internal.taglib.component;
 
+import org.apache.myfaces.tobago.apt.annotation.Behavior;
 import org.apache.myfaces.tobago.apt.annotation.DynamicExpression;
-import org.apache.myfaces.tobago.apt.annotation.Facet;
 import org.apache.myfaces.tobago.apt.annotation.Tag;
 import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;
-import org.apache.myfaces.tobago.component.Facets;
+import org.apache.myfaces.tobago.component.ClientBehaviors;
 import org.apache.myfaces.tobago.component.RendererTypes;
-import org.apache.myfaces.tobago.internal.taglib.declaration.HasCurrentMarkup;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasIdBindingAndRendered;
-import org.apache.myfaces.tobago.internal.taglib.declaration.HasMarkup;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasTip;
-import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutComponent;
+import org.apache.myfaces.tobago.internal.taglib.declaration.IsVisual;
 
-import javax.faces.component.UIOutput;
+import jakarta.faces.component.UIOutput;
 
 /**
  * Renders a progress bar.
@@ -41,26 +39,33 @@ import javax.faces.component.UIOutput;
 @Tag(name = "progress")
 @UIComponentTag(
     uiComponent = "org.apache.myfaces.tobago.component.UIProgress",
-    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUIOut",
-    uiComponentFacesClass = "javax.faces.component.UIOutput",
+    uiComponentFacesClass = "jakarta.faces.component.UIOutput",
     componentFamily = UIOutput.COMPONENT_FAMILY,
     rendererType = RendererTypes.PROGRESS,
     allowedChildComponenents = "NONE",
-    facets = {@Facet(
-        name = Facets.COMPLETE,
-        description =
-            "Contains an instance of UICommand (tc:command). The action is invoked if the full progress has reached",
-        allowedChildComponenents = "org.apache.myfaces.tobago.Command")})
+    behaviors = {
+        @Behavior(
+            name = ClientBehaviors.COMPLETE,
+            isDefault = true)
+    }
+)
 
-public interface ProgressTagDeclaration
-    extends HasIdBindingAndRendered, HasTip, HasMarkup, HasCurrentMarkup, IsGridLayoutComponent {
+public interface ProgressTagDeclaration extends HasIdBindingAndRendered, HasTip, IsVisual {
 
   /**
-   * The current value of this component.
+   * The current value of this component. May be a java.lang.Number or a javax.swing.BoundedRangeModel
    */
   @TagAttribute
   @UIComponentTagAttribute(
-      type = {"javax.swing.BoundedRangeModel"},
+      type = {"javax.swing.BoundedRangeModel", "java.lang.Double"},
       expression = DynamicExpression.VALUE_EXPRESSION_REQUIRED)
   void setValue(String value);
+
+  /**
+   * The maximum of the value of the progress.
+   */
+  @TagAttribute
+  @UIComponentTagAttribute(
+      type = {"java.lang.Double"})
+  void setMax(String max);
 }
